@@ -5,6 +5,7 @@
  */
 
 #include "individualmaildialog.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KGuiItem>
 #include <KLocalizedString>
@@ -23,6 +24,8 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
                                            const KGuiItem &buttonNo,
                                            QWidget *parent)
     : QDialog(parent)
+    , m_buttons(new QDialogButtonBox(this))
+
 {
     setWindowTitle(i18nc("@title:window", "Group Scheduling Email"));
     m_detailsWidget = new QWidget();
@@ -53,7 +56,6 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
     topLayout->addWidget(mW);
     topLayout->addWidget(m_detailsWidget);
 
-    m_buttons = new QDialogButtonBox(this);
     m_buttons->setStandardButtons(QDialogButtonBox::Yes | QDialogButtonBox::No | QDialogButtonBox::Help);
     auto yesButton = m_buttons->button(QDialogButtonBox::Yes);
     yesButton->setText(buttonYes.text());
@@ -66,7 +68,7 @@ IndividualMailDialog::IndividualMailDialog(const QString &question,
         done(QDialogButtonBox::No);
     });
     auto detailsButton = m_buttons->button(QDialogButtonBox::Help);
-    detailsButton->setIcon(QIcon::fromTheme(QStringLiteral("help-about")));
+    detailsButton->setIcon(QIcon::fromTheme(u"help-about"_s));
     connect(detailsButton, &QPushButton::clicked, this, [this]() {
         m_detailsWidget->setVisible(!m_detailsWidget->isVisible());
         updateButtonState();
