@@ -12,13 +12,13 @@ using namespace IncidenceEditorNG;
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    QApplication const app(argc, argv);
     QCommandLineParser parser;
     parser.addVersionOption();
     parser.addHelpOption();
     parser.process(app);
 
-    auto *dialog = new ResourceManagement();
+    auto dialog = new ResourceManagement();
 
     dialog->show();
 
